@@ -19,9 +19,9 @@ import subprocess
 import sys
 
 # Current version
-version_major = 1
-version_minor = 5
-version_micro = 0
+version_major = 2
+version_minor = 0
+version_micro = 1
 version_extra = "" # leave empty for release
 
 # Expected by setup.py: string of form "X.Y.Z"
@@ -109,8 +109,8 @@ VERSION = __version__
 CLASSIFIERS = CLASSIFIERS
 PLATFORMS = 'OS Independent'
 REQUIRES = [
-    'populse_mia==1.5.0',
-    'populse_db==1.5.0'
+    'populse_mia==2.*',
+    'populse_db>=2.0.0'
 ]
 EXTRA_REQUIRES = {
     'doc': [
